<?php

require_once('ReportAggregator.class.php');
require_once('TextReportAggregator.class.php');

include_once('geshi/geshi.php');
require_once('HtmlReportAggregator.class.php');

require_once('reports/Report.class.php');
require_once('reports/QueriesByTypeReport.class.php');
require_once('reports/OverallStatsReport.class.php');
require_once('reports/SlowestQueriesReport.class.php');
require_once('reports/NormalizedReport.class.php');
require_once('reports/NormalizedQueriesMostTimeReport.class.php');
require_once('reports/NormalizedQueriesMostFrequentReport.class.php');
require_once('reports/NormalizedQueriesSlowestAverageReport.class.php');

require_once('reports/NormalizedErrorsReport.class.php');
require_once('reports/NormalizedErrorsMostFrequentReport.class.php');

?>